@@ -1,21 +1,12 @@
+# $Id$
 
 package Google::Chart::Type::XY;
 use Moose;
-use namespace::clean -except => qw(meta);
+use constant parameter_value => 'lxy';
 
-extends 'Google::Chart';
+with 'Google::Chart::Type::Simple';
 
-sub _build_type { 'lxy' };
-
-with qw(
-    Google::Chart::WithAxis
-    Google::Chart::WithData
-    Google::Chart::WithGrid
-    Google::Chart::WithLineStyle
-    Google::Chart::WithMarker
-);
-
-__PACKAGE__->meta->make_immutable();
+no Moose;
 
 1;
 
